@@ -11,16 +11,16 @@ class AgenticLLMInputs(TypedDict, total=False):
     user_prompt: str
     max_llm_calls: Annotated[int, StepTypeConfig(is_config=True)]
     openai_api_key: Annotated[
-        str, StepTypeConfig(is_config=True, or_op=["patched_api_key", "google_api_key", "anthropic_api_key"])
+        str, StepTypeConfig(is_config=True, or_op=["patched_api_key", "google_api_key", "client_is_gcp", "anthropic_api_key"])
     ]
     anthropic_api_key: Annotated[
-        str, StepTypeConfig(is_config=True, or_op=["patched_api_key", "google_api_key", "openai_api_key"])
+        str, StepTypeConfig(is_config=True, or_op=["patched_api_key", "google_api_key", "client_is_gcp", "openai_api_key"])
     ]
     patched_api_key: Annotated[
         str,
         StepTypeConfig(
             is_config=True,
-            or_op=["openai_api_key", "google_api_key", "anthropic_api_key"],
+            or_op=["openai_api_key", "google_api_key", "client_is_gcp", "anthropic_api_key"],
             msg=f"""\
 Model API key not found.
 Please login at: "{TOKEN_URL}"
@@ -31,7 +31,10 @@ If you are using a OpenAI API Key, please set `--openai_api_key=<token>`.""",
         ),
     ]
     google_api_key: Annotated[
-        str, StepTypeConfig(is_config=True, or_op=["patched_api_key", "openai_api_key", "anthropic_api_key"])
+        str, StepTypeConfig(is_config=True, or_op=["patched_api_key", "openai_api_key", "anthropic_api_key", "client_is_gcp"])
+    ]
+    client_is_gcp: Annotated[
+        str, StepTypeConfig(is_config=True, or_op=["patched_api_key", "openai_api_key", "anthropic_api_key", "google_api_key"])
     ]
 
 
